/* IMPORT */
import * as Highlighter from 'tokens-highlighter';
import Oniguruma from './textmate/oniguruma.js';
import Registry from './textmate/registry.js';
import Tokenizer from './textmate/tokenizer.js';
/* MAIN */
class TextMateHighlighter {
    /* CONSTRUCTOR */
    constructor(options) {
        /* API */
        this.highlightToAbstract = async (options, highlighter) => {
            const lines = options.code.replace(/^(\r?\n|\r)+|(\r?\n|\r)+$/g, '').split(/\r?\n|\r/g);
            const tokens = new Array(lines.length).fill([]);
            await this.tokenize(lines, options.grammar, options.theme, options.signal, (lineTokens, lineIndex) => {
                tokens[lineIndex] = lineTokens;
            });
            const backgroundColor = options.background || (await this.registry.loadThemeColorsDefault(options.theme)).background;
            const result = highlighter(tokens, { backgroundColor });
            return result;
        };
        this.highlightToANSI = (options) => {
            return this.highlightToAbstract(options, Highlighter.toANSI);
        };
        this.highlightToDOM = (options) => {
            return this.highlightToAbstract(options, Highlighter.toDOM);
        };
        this.highlightToHighlights = (options) => {
            return this.highlightToAbstract(options, Highlighter.toHighlights);
        };
        this.highlightToHTML = (options) => {
            return this.highlightToAbstract(options, Highlighter.toHTML);
        };
        this.tokenize = (lines, grammar, theme, signal, onTokens) => {
            return this.tokenizer.tokenize(lines, grammar, theme, signal, onTokens);
        };
        const { getGrammar, getOniguruma, getTheme } = options;
        this.oniguruma = new Oniguruma({ getOniguruma });
        this.registry = new Registry({ getGrammar, getTheme, getOniguruma: () => this.oniguruma.load() });
        this.tokenizer = new Tokenizer(this.registry);
    }
}
/* EXPORT */
export default TextMateHighlighter;
