/* IMPORT */
import isShallowEqual from 'are-shallow-equal';
/* MAIN */
const isString = (value) => {
    return typeof value === 'string';
};
const memoize = (fn) => {
    const cache = new Map();
    return (...args) => {
        const id = args[0];
        const resultCached = cache.get(id);
        if (resultCached !== undefined || cache.has(id))
            return resultCached;
        const result = fn.apply(undefined, args);
        cache.set(id, result);
        return result;
    };
};
const once = (fn) => {
    let called = false;
    let result;
    return () => {
        if (!called) {
            called = true;
            result = fn();
        }
        return result;
    };
};
/* EXPORT */
export { isShallowEqual, isString, memoize, once };
